==> Tekkotsu_2.2.1.tar.gz: Tekkotsu_2.2.1/Behaviors/Mon/SpeakerServer.h <==
//-*-c++-*-
#ifndef INCLUDED_SpeakerServer_h_
#define INCLUDED_SpeakerServer_h_

#include "Behaviors/BehaviorBase.h"
#include "SoundPlay/SoundManager.h"

//! Plays streamed audio via the speaker
class SpeakerServer : public BehaviorBase {
	public:
		static SpeakerServer* GetInstance();
		virtual ~SpeakerServer();
		
		virtual void DoStart();
		virtual void DoStop();
		
		static int socket_callback(char *buf, int size);
	
	private:
		SpeakerServer();
		SpeakerServer(const SpeakerServer& rhs);
		SpeakerServer& operator=(const SpeakerServer& rhs);
		static SpeakerServer* instance;
		
		int GotSocketData(char* data, int dataSize);
		class Socket *socket;
		static short GetShort(const void* buf) { short result; memcpy(&result, buf, sizeof(short)); return result; }
		
		static const int MAX_PACKET_SIZE = 1024 * 1024;
		static const int RECEIVE_BUFFER_SIZE = 2048;
	
		class Packet {
			public:
				Packet();
				virtual ~Packet();
				
				class Buffer* header;
				int size;
				int type;
				bool skipped;
				
				class Buffer* pcmHeader;
				unsigned short sampleRate;
				byte sampleBits;
				
				class Buffer* samples;
			
			private:
				Packet(const Packet& rhs);
				Packet& operator=(const Packet& rhs);
		};
		
		Packet packet; 
		class Buffer* frame;
		class Buffer* resampled;
		
		void AddPacket(
			const void* samples, int samplesSize, int sampleRate, byte sampleBits);
		const void* ResampleForSpeaker(
			const void* samples,
			int samplesSize,
			int sampleRate,
			byte bitsPerSample,
			int& newSamplesSize);
				
		void QueueFrame(const char* samples, int samplesSize);
		SoundManager::Play_ID channel;
};
#endif

==> Tekkotsu_2.4.1.tar.gz: Tekkotsu_2.4.1/Behaviors/Mon/SpeakerServer.h <==
//-*-c++-*-
#ifndef INCLUDED_SpeakerServer_h_
#define INCLUDED_SpeakerServer_h_

#include "Behaviors/BehaviorBase.h"
#include "Sound/SoundManager.h"

//! Plays streamed audio via the speaker
class SpeakerServer : public BehaviorBase {
	public:
		static SpeakerServer* GetInstance();
		virtual ~SpeakerServer();
		
		virtual void DoStart();
		virtual void DoStop();
		
		static int socket_callback(char *buf, int size);
	
	private:
		SpeakerServer();
		SpeakerServer(const SpeakerServer& rhs); //!< don't call
		SpeakerServer& operator=(const SpeakerServer& rhs); //!< don't call
		static SpeakerServer* instance;
		
		int GotSocketData(char* data, int dataSize);
		class Socket *socket;
		static short GetShort(const void* buf) { short result; memcpy(&result, buf, sizeof(short)); return result; }
		
		static const int MAX_PACKET_SIZE = 1024 * 1024;
		static const int RECEIVE_BUFFER_SIZE = 2048;
	
		class Packet {
			public:
				Packet();
				virtual ~Packet(); 
				
				class Buffer* header;
				int size;
				int type;
				bool skipped;
				
				class Buffer* pcmHeader;
				unsigned short sampleRate;
				byte sampleBits;
				
				class Buffer* samples;
			
			private:
				Packet(const Packet& rhs); //!< don't call
				Packet& operator=(const Packet& rhs); //!< don't call
		};
		
		Packet packet; 
		class Buffer* frame;
		class Buffer* resampled;
		
		void AddPacket(
			const void* samples, int samplesSize, int sampleRate, byte sampleBits);
		const void* ResampleForSpeaker(
			const void* samples,
			int samplesSize,
			int sampleRate,
			byte bitsPerSample,
			int& newSamplesSize);
				
		void QueueFrame(const char* samples, int samplesSize);
		SoundManager::Play_ID channel;
};
#endif
